@@ -25,7 +25,7 @@
 #include "timelineview_p.h"
 #include "timelineitem.h"
 
-#include <KDGantt2/KDGanttGraphicsView>
+#include <KGantt/KGanttGraphicsView>
 
 #include <Akonadi/Calendar/ETMCalendar>
 #include <CalendarSupport/CollectionSelection>
